pub struct MemoryTicketQueue(Arc<RwLock<BinaryHeap<Reverse<RedeemableTicket>>>>);Expand description
Simple in-memory ticket queue implementation using a binary heap.
This is suitable for testing where ticket persistence is not required.
The implementation might not be particularly efficient for production use.
Tuple Fields
0: Arc<RwLock<BinaryHeap<Reverse<RedeemableTicket>>>>Trait Implementations
Sourceimpl Clone for MemoryTicketQueue
impl Clone for MemoryTicketQueue
Sourcefn clone(&self) -> MemoryTicketQueue
fn clone(&self) -> MemoryTicketQueue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MemoryTicketQueue
impl Debug for MemoryTicketQueue
Sourceimpl Default for MemoryTicketQueue
impl Default for MemoryTicketQueue
Sourcefn default() -> MemoryTicketQueue
fn default() -> MemoryTicketQueue
Returns the “default value” for a type. Read more
Sourceimpl TicketQueue for MemoryTicketQueue
impl TicketQueue for MemoryTicketQueue
type Error = Infallible
Sourcefn push(&mut self, ticket: RedeemableTicket) -> Result<(), Self::Error>
fn push(&mut self, ticket: RedeemableTicket) -> Result<(), Self::Error>
Add a ticket to the queue.
Sourcefn pop(&mut self) -> Result<Option<RedeemableTicket>, Self::Error>
fn pop(&mut self) -> Result<Option<RedeemableTicket>, Self::Error>
Remove and return the next ticket in-order from the queue. Read more
Sourcefn peek(&self) -> Result<Option<RedeemableTicket>, Self::Error>
fn peek(&self) -> Result<Option<RedeemableTicket>, Self::Error>
Return the next ticket in-order from the queue without removing it. Read more
Sourcefn iter_unordered(
&self,
) -> Result<impl Iterator<Item = Result<RedeemableTicket, Self::Error>>, Self::Error>
fn iter_unordered( &self, ) -> Result<impl Iterator<Item = Result<RedeemableTicket, Self::Error>>, Self::Error>
Iterate over all tickets in the queue in arbitrary order. Read more